@@ -1,14 +1,14 @@
 #' Create a file with DB access credentials
-#' @description Creates a file containing access
-#' credentials for a database.
-#' @param file a file path for the credentials file
-#' to be stored on disk.
-#' @param dbname the database name.
-#' @param host the \code{host} name.
-#' @param port the port number.
-#' @param user the username for the database
-#' @param password the password associated with the
-#' \code{user}.
+#'
+#' Creates a file containing access credentials for a database.
+#' 
+#' @param file A file path for the credentials file to be stored on disk.
+#' @param dbname The database name.
+#' @param host The `host` name.
+#' @param port The port number.
+#' @param user The username for the database
+#' @param password The password associated with the `user`.
+#' 
 #' @examples
 #' \dontrun{
 #' # Create a credentials file for access to
@@ -23,8 +23,8 @@
 #'   user = "********",
 #'   password = "****************")
 #' }
-#' @export create_creds_file
-
+#' 
+#' @export
 create_creds_file <- function(file,
                               dbname,
                               host,
@@ -39,9 +39,9 @@ create_creds_file <- function(file,
     host = as.character(host),
     port = as.character(port),
     user = as.character(user),
-    password = as.character(password))
+    password = as.character(password)
+  )
   
   # Save the credential values as a file
   saveRDS(credentials, file = file)
 }
-  
\ No newline at end of file
