@@ -2,9 +2,6 @@ context("Creation of validation steps")
 
 test_that("Creating a `col_is_character()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_is_character()` function to create
   # a validation step
   validation <-
@@ -36,7 +33,7 @@ test_that("Creating a `col_is_character()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -66,9 +63,6 @@ test_that("Creating a `col_is_character()` step is possible", {
 
 test_that("Creating a `col_is_date()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_is_date()` function to create
   # a validation step
   validation <-
@@ -100,7 +94,7 @@ test_that("Creating a `col_is_date()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -130,9 +124,6 @@ test_that("Creating a `col_is_date()` step is possible", {
 
 test_that("Creating a `col_is_factor()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_is_factor()` function to create
   # a validation step
   validation <-
@@ -164,7 +155,7 @@ test_that("Creating a `col_is_factor()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -194,9 +185,6 @@ test_that("Creating a `col_is_factor()` step is possible", {
 
 test_that("Creating a `col_is_integer()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_is_integer()` function to create
   # a validation step
   validation <-
@@ -228,7 +216,7 @@ test_that("Creating a `col_is_integer()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -258,9 +246,6 @@ test_that("Creating a `col_is_integer()` step is possible", {
 
 test_that("Creating a `col_is_logical()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_is_logical()` function to create
   # a validation step
   validation <-
@@ -292,7 +277,7 @@ test_that("Creating a `col_is_logical()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -322,9 +307,6 @@ test_that("Creating a `col_is_logical()` step is possible", {
 
 test_that("Creating a `col_is_numeric()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_is_numeric()` function to create
   # a validation step
   validation <-
@@ -356,7 +338,7 @@ test_that("Creating a `col_is_numeric()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -386,9 +368,6 @@ test_that("Creating a `col_is_numeric()` step is possible", {
 
 test_that("Creating a `col_is_posix()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_is_posix()` function to create
   # a validation step
   validation <-
@@ -420,7 +399,7 @@ test_that("Creating a `col_is_posix()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -450,9 +429,6 @@ test_that("Creating a `col_is_posix()` step is possible", {
 
 test_that("Creating a `col_vals_between()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_between()` function to create
   # a validation step
   validation <-
@@ -489,7 +465,7 @@ test_that("Creating a `col_vals_between()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -522,9 +498,6 @@ test_that("Creating a `col_vals_between()` step is possible", {
 
 test_that("Creating a `col_vals_not_between()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_not_between()` function to create
   # a validation step
   validation <-
@@ -561,7 +534,7 @@ test_that("Creating a `col_vals_not_between()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -594,9 +567,6 @@ test_that("Creating a `col_vals_not_between()` step is possible", {
 
 test_that("Creating a `col_vals_equal()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_equal()` function to create
   # a validation step
   validation <-
@@ -630,7 +600,7 @@ test_that("Creating a `col_vals_equal()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -662,9 +632,6 @@ test_that("Creating a `col_vals_equal()` step is possible", {
 
 test_that("Creating a `col_vals_not_equal()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_not_equal()` function to create
   # a validation step
   validation <-
@@ -698,7 +665,7 @@ test_that("Creating a `col_vals_not_equal()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -730,9 +697,6 @@ test_that("Creating a `col_vals_not_equal()` step is possible", {
 
 test_that("Creating a `col_vals_gt()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_gt()` function to create
   # a validation step
   validation <-
@@ -766,7 +730,7 @@ test_that("Creating a `col_vals_gt()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -798,9 +762,6 @@ test_that("Creating a `col_vals_gt()` step is possible", {
 
 test_that("Creating a `col_vals_gte()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_gte()` function to create
   # a validation step
   validation <-
@@ -834,7 +795,7 @@ test_that("Creating a `col_vals_gte()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -866,9 +827,6 @@ test_that("Creating a `col_vals_gte()` step is possible", {
 
 test_that("Creating a `col_vals_lt()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_lt()` function to create
   # a validation step
   validation <-
@@ -902,7 +860,7 @@ test_that("Creating a `col_vals_lt()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -934,9 +892,6 @@ test_that("Creating a `col_vals_lt()` step is possible", {
 
 test_that("Creating a `col_vals_lte()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_lte()` function to create
   # a validation step
   validation <-
@@ -970,7 +925,7 @@ test_that("Creating a `col_vals_lte()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -1002,9 +957,6 @@ test_that("Creating a `col_vals_lte()` step is possible", {
 
 test_that("Creating a `col_vals_in_set()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_in_set()` function to create
   # a validation step
   validation <-
@@ -1040,7 +992,7 @@ test_that("Creating a `col_vals_in_set()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -1072,9 +1024,6 @@ test_that("Creating a `col_vals_in_set()` step is possible", {
 
 test_that("Creating a `col_vals_not_in_set()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_not_in_set()` function to create
   # a validation step
   validation <-
@@ -1110,7 +1059,7 @@ test_that("Creating a `col_vals_not_in_set()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -1142,9 +1091,6 @@ test_that("Creating a `col_vals_not_in_set()` step is possible", {
 
 test_that("Creating a `col_vals_regex()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_regex()` function to create
   # a validation step
   validation <-
@@ -1178,7 +1124,7 @@ test_that("Creating a `col_vals_regex()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -1210,9 +1156,6 @@ test_that("Creating a `col_vals_regex()` step is possible", {
 
 test_that("Creating a `col_vals_null()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_null()` function to create
   # a validation step
   validation <-
@@ -1244,7 +1187,7 @@ test_that("Creating a `col_vals_null()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -1274,9 +1217,6 @@ test_that("Creating a `col_vals_null()` step is possible", {
 
 test_that("Creating a `col_vals_not_null()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `col_vals_not_null()` function to create
   # a validation step
   validation <-
@@ -1308,7 +1248,7 @@ test_that("Creating a `col_vals_not_null()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -1338,9 +1278,6 @@ test_that("Creating a `col_vals_not_null()` step is possible", {
 
 test_that("Creating a `rows_not_duplicated()` step is possible", {
   
-  library(tibble)
-  library(dplyr)
-  
   # Use `rows_not_duplicated()` function to create
   # a validation step
   validation <-
@@ -1372,7 +1309,7 @@ test_that("Creating a `rows_not_duplicated()` step is possible", {
   expect_true(is.na(validation$validation_set$n_failed))
   expect_true(is.na(validation$validation_set$f_passed))
   expect_true(is.na(validation$validation_set$f_failed))
-  expect_equivalent(validation$validation_set$warn_count, 1)
+  expect_true(is.na(validation$validation_set$warn_count))
   expect_true(is.na(validation$validation_set$notify_count))
   expect_true(is.na(validation$validation_set$warn))
   expect_true(is.na(validation$validation_set$notify))
@@ -1383,4 +1320,3 @@ test_that("Creating a `rows_not_duplicated()` step is possible", {
                     system.file("extdata", "small_table.csv",
                                 package = "pointblank"))
 })
-
